%define oname	biopython
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

Summary:	The Biopython Project
Name:		python-biopython
Epoch:		1
Version:	1.84
Release:	%mkrel 3
License:	BSD
Group:		Sciences/Biology
Url:		https://biopython.org/
Source0:	https://biopython.org/DIST/%{oname}-%{version}.tar.gz
Patch1:		biopython-1.84-linking.patch
Patch2:		python-biopython-1.84-replace_deprecated_function.patch
BuildRequires:	flex
BuildRequires:	gcc

%description
The Biopython Project is an international association of developers of
freely available Python tools for computational molecular biology.

http://biopython.org provides an online resource for modules,
scripts, and web links for developers of Python-based software for
life science research.

This package provides various Python modules from the Biopython Project
used to process biological data.

%package	-n python3-biopython
Summary:	The Biopython Project for Python3
Group:		Sciences/Biology
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:	python3-reportlab
BuildRequires:	python3-numpy
BuildRequires:	python3-numpy-devel
Requires:	python3-numpy
Requires:	python3-reportlab
Recommends:	ncbi-blast
# don't explicitly require clustalw because it is non-free
Recommends:	clustalw
%{?python_provide:%python_provide python3-biopython}

Obsoletes:	wise2 < 2.4.1-11

%description -n python3-biopython
The Biopython Project is an international association of developers of
freely available Python tools for computational molecular biology.

http://biopython.org provides an online resource for modules,
scripts, and web links for developers of Python-based software for
life science research.

This package provides various Python 3 modules from the Biopython Project
used to process biological data.

%package	-n python3-biopython-sql
Summary:	Code for using Biopython with BioSQL databases
Group:		Development/Python
Requires:	python3-biopython = %{epoch}:%{version}-%{release}
Requires:	python3-psycopg2

%description -n python3-biopython-sql
BioSQL is meant to be a common data storage layer supported by all the
different Bio* projects, Bioperl, Biojava, Biopython, and Bioruby.
Entries stored through an application written in, say, Bioperl could
be retrieved by another written in Biojava.

%package	doc
Summary:	The Biopython Project documentation
Group:		Development/Python
Provides:	biopython-doc

%description doc
This package provides the documentation for the various components of the
Biopython Project.

%prep
%autosetup -p1 -n %{oname}-%{version}

# remove all execute bits from documentation and fix line endings
find Scripts -type f -exec chmod -x {} 2>/dev/null ';'
find Doc -type f -exec chmod -x {} 2>/dev/null ';'
find Doc -type f -exec sed -i 's/\r//' {} 2>/dev/null ';'

# remove execute bits from Python modules
find Bio -type f -exec chmod -x {} 2>/dev/null ';'
# remove she-bang lines in .py files to keep rpmlint happy
find Bio -type f -name "*.py" -exec sed -i '/^#![ ]*\/usr\/bin\/.*$/ d' {} 2>/dev/null ';'

%generate_buildrequires
%pyproject_buildrequires -x tests

%build
%pyproject_wheel

%install
%pyproject_install

%files doc
%doc Doc/*.pdf Doc/examples/

%files -n python3-biopython
%{python3_sitearch}/Bio
%{python3_sitearch}/*.dist-info
%doc Scripts
%doc CONTRIB.rst DEPRECATED.rst NEWS.rst README.rst
%license LICENSE.rst

%files -n python3-biopython-sql
%{python3_sitearch}/BioSQL
%license LICENSE.rst


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 1:1.84-3.mga10
+ Revision: 2242300
- Mageia 10 Mass Rebuild

* Mon Mar 03 2025 wally <wally> 1:1.84-2.mga10
+ Revision: 2159633
- rebuild for python3.13

* Sat Sep 28 2024 daviddavid <daviddavid> 1:1.84-1.mga10
+ Revision: 2101826
- new version: 1.84
- remove and obsolete no longer needed wise2 dependency
- switch to pyproject
- rebuild against numpy 2

* Tue May 14 2024 papoteur <papoteur> 1:1.83-1.mga10
+ Revision: 2064156
- remove upstreamed patch
- rediff patch for linking
- new version 1.83

* Thu Dec 28 2023 daviddavid <daviddavid> 1:1.81-1.mga10
+ Revision: 2023147
- new version: 1.81
- rebuild for py3.12

* Wed Apr 06 2022 umeabot <umeabot> 1:1.79-2.mga9
+ Revision: 1846082
- Mageia 9 Mass Rebuild

* Sat Feb 26 2022 mrambo3501 <mrambo3501> 1:1.79-1.mga9
+ Revision: 1785744
- version 1.79
- rebuild for python-3.10

* Sat Mar 20 2021 daviddavid <daviddavid> 1:1.78-2.mga9
+ Revision: 1705408
- rebuild for python 3.9

* Sat Nov 07 2020 guillomovitch <guillomovitch> 1:1.78-1.mga8
+ Revision: 1643273
- new version 1.78

* Tue Jun 09 2020 daviddavid <daviddavid> 1:1.77-1.mga8
+ Revision: 1591128
- new version: 1.77

* Thu Feb 20 2020 umeabot <umeabot> 1:1.76-2.mga8
+ Revision: 1546117
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 1:1.76-1.mga8
+ Revision: 1486025
- new version: 1.76

* Wed Nov 13 2019 daviddavid <daviddavid> 1:1.75-1.mga8
+ Revision: 1459722
- new version: 1.75

* Tue Sep 17 2019 tv <tv> 1:1.74-1.mga8
+ Revision: 1442983
- new release
- drop BR on epydoc
- rebuild for python-3.8

* Wed Aug 28 2019 daviddavid <daviddavid> 1:1.73-2.mga8
+ Revision: 1434676
- drop py2 support
- python3-biopython-sql requires python3-biopython

* Wed Jan 09 2019 shlomif <shlomif> 1:1.73-1.mga7
+ Revision: 1353138
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 1:1.66-5.mga7
+ Revision: 1300447
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 1:1.66-4.mga7
+ Revision: 1135322
- Rebuild for python 3.6

* Mon Mar 07 2016 philippem <philippem> 1:1.66-3.mga6
+ Revision: 987004
- change requires to wise2
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Dec 12 2015 philippem <philippem> 1:1.66-1.mga6
+ Revision: 909689
- update to 1.66

* Sun Oct 11 2015 philippem <philippem> 1:1.65-1.mga6
+ Revision: 889663
- update to 1.65

* Sat Oct 10 2015 tv <tv> 1:1.64-5.mga6
+ Revision: 888986
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 1:1.64-4.mga5
+ Revision: 743570
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:1.64-3.mga5
+ Revision: 728107
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:1.64-2.mga5
+ Revision: 687904
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Tue Aug 05 2014 philippem <philippem> 1:1.64-1.mga5
+ Revision: 659978
- update to 1.64

* Sat May 31 2014 pterjan <pterjan> 1:1.63-4.mga5
+ Revision: 629727
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 1:1.63-3.mga5
+ Revision: 628471
- Rebuild for new Python

* Tue Apr 01 2014 philippem <philippem> 1:1.63-2.mga5
+ Revision: 611194
- remove dependency on python3-mysql that don't exists yet

* Sun Mar 30 2014 philippem <philippem> 1:1.63-1.mga5
+ Revision: 610443
- update to 1.63, add Python 3

* Tue Oct 22 2013 umeabot <umeabot> 1:1.62-3.mga4
+ Revision: 543231
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1:1.62-2.mga4
+ Revision: 498192
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 16 2013 philippem <philippem> 1:1.62-1.mga4
+ Revision: 480287
- update to 1.62

* Thu Jul 04 2013 philippem <philippem> 1:1.61-1.mga4
+ Revision: 450202
- Update to 1.61

* Sun Jan 13 2013 umeabot <umeabot> 1:1.60-2.mga3
+ Revision: 378504
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 02 2012 philippem <philippem> 1:1.60-1.mga3
+ Revision: 287233
- New upstream release 1.60

* Sat Aug 20 2011 fwang <fwang> 1:1.58-1.mga2
+ Revision: 134498
- new verison 1.58
+ ahmad <ahmad>
- finalise renaming the package to python-biopython
- only suggest ncbi-blast, it's optional (according to the README, and the Debian
  biopython package)

* Mon Mar 28 2011 ennael <ennael> 1:1.56-1.mga1
+ Revision: 78433
- fix build (thanks to rtp)
- clean spec file
- imported package biopython

